@@ -4,11 +4,10 @@ print(os.getcwd())
 from PyQt5.QtCore import Qt
 from PyQt5.QtGui import *
 from PyQt5.QtWidgets import *
-from wsl import *
+from synesthesia.wsl import *
 from PIL.ImageQt import ImageQt
-from art_generator import tests, qt_canvas
-# from essentia_helper import *
-from lib import notes_to_canvas
+from synesthesia.art_generator import qt_canvas, process_audio
+from synesthesia.images import *
 
 class Window(QWidget):
     def __init__(self):
@@ -29,10 +28,10 @@ class Window(QWidget):
 
         # line seperators
         sep = QPixmap('./images/line.png')
-        sep = sep.scaled(610, 1)
+        sep = sep.scaled(700, 1)
         self.mid_line = QLabel(self)
         self.mid_line.setPixmap(sep)
-        self.mid_line.move(-10, 190)
+        self.mid_line.move(-50, 190)
         sep = sep.scaled(1, 450)  # rotate vertically
         self.vert_line = QLabel(self)
         self.vert_line.setPixmap(sep)
@@ -40,7 +39,7 @@ class Window(QWidget):
 
         # select file label
         self.select_file = QLabel(self)
-        self.select_file.move(10, 153)
+        self.select_file.move(8, 153)
         self.select_file.setText('Audio File:')
 
         # input for folder path
@@ -56,7 +55,7 @@ class Window(QWidget):
 
         # select algorithm label
         self.select_algo = QLabel(self)
-        self.select_algo.move(10, 200)
+        self.select_algo.move(8, 202)
         self.select_algo.setText('Algorithm:')
 
         # ComboBox for different algorithms
@@ -65,110 +64,104 @@ class Window(QWidget):
         self.algo_combo.resize(120, 20)
         algos = [
             '',  # blank so when displayed nothing is autoselected
-            'Algorithm 1',
-            'Algorithm 2',
-            'Algorithm 3',
-            'Algorithm 4',
-            'Algorithm 5',
+            'Shape of You',
+            'Line Rider',
+            'Curvy',
         ]
         self.algo_combo.addItems(algos)
         self.algo_combo.activated[str].connect(self.on_algo_change)
 
         # label for algorithm label
         self.algo_lbl = QLabel(self)
-        self.algo_lbl.move(25, 375)
+        self.algo_lbl.move(25, 300)
         self.algo_lbl.setWordWrap(True)
         self.algo_lbl.setAlignment(Qt.AlignCenter)
  
-        # Tempo Slider
-        self.tempo_lbl = QLabel(self)
-        self.tempo_lbl.setText('Tempo:')
-        self.tempo_lbl.move(10, 225)
-        self.tempo_val = QLabel(self)
-        self.tempo_val.move(165, 225)
-        self.tempo_val.resize(35, 10)
-        self.tempo_val.setText('0%')
-        self.tempo_sld = QSlider(Qt.Horizontal, self)
-        self.tempo_sld.setRange(-100, 100)
-        self.tempo_sld.setFocusPolicy(Qt.NoFocus)
-        self.tempo_sld.setPageStep(1)
-        self.tempo_sld.move(75, 225)
-        self.tempo_sld.valueChanged.connect(
-            lambda val: self.tempo_val.setText(str(val) + '%'))
-            
-          # Frequency Slider
+    # sr Slider
+        sr_tt = 'Determines the number of samples taken per second of audio'
+        self.sr_lbl = QLabel(self)
+        self.sr_lbl.setText('Sample Rate:')
+        self.sr_lbl.move(8, 225)
+        self.sr_lbl.setToolTip(sr_tt)
+        self.sr_val = QLabel(self)
+        self.sr_val.move(170, 227)
+        self.sr_val.resize(35, 10)
+        self.sr_val.setText('11.5k')
+        self.sr_val.setFont(QFont('', 8))
+        self.sr_val.setToolTip(sr_tt)
+        self.sr_sld = QSlider(Qt.Horizontal, self)
+        self.sr_sld.setRange(1000, 22050)
+        self.sr_sld.setValue(11525)
+        self.sr_sld.setFocusPolicy(Qt.NoFocus)
+        self.sr_sld.setPageStep(1)
+        self.sr_sld.setToolTip(sr_tt)
+        self.sr_sld.move(90, 226)
+        self.sr_sld.resize(75,15)
+        self.sr_sld.valueChanged.connect(
+            lambda val: self.sr_val.setText(str(round(val/1000,1)) + 'k'))
+
+    # Frequency Slider
+        frq_tt = 'Increases or decreases the frequencies by the percent selected'
         self.frq_lbl = QLabel(self)
         self.frq_lbl.setText('Frequency:')
-        self.frq_lbl.move(10, 250)
+        self.frq_lbl.move(8, 250)
+        self.frq_lbl.setToolTip(frq_tt)
         self.frq_val = QLabel(self)
-        self.frq_val.move(165, 250)
+        self.frq_val.move(170, 252)
         self.frq_val.resize(35, 10)
         self.frq_val.setText('0%')
+        self.frq_val.setFont(QFont('', 8))
+        self.frq_val.setToolTip(frq_tt)
         self.frq_sld = QSlider(Qt.Horizontal, self)
-        self.frq_sld.setRange(-100, 100)
+        self.frq_sld.setRange(-99, 100)
         self.frq_sld.setFocusPolicy(Qt.NoFocus)
         self.frq_sld.setPageStep(1)
-        self.frq_sld.move(75, 250)
+        self.frq_sld.setToolTip(frq_tt)
+        self.frq_sld.move(90, 251)
+        self.frq_sld.resize(75,15)
         self.frq_sld.valueChanged.connect(
             lambda val: self.frq_val.setText(str(val) + '%'))
 
-        # Tone Slider
-        self.tone_lbl = QLabel(self)
-        self.tone_lbl.setText('Tone:')
-        self.tone_lbl.move(10, 275)
-        self.tone_val = QLabel(self)
-        self.tone_val.move(165, 275)
-        self.tone_val.resize(35, 10)
-        self.tone_val.setText('0%')
-        self.tone_sld = QSlider(Qt.Horizontal, self)
-        self.tone_sld.setRange(-100, 100)
-        self.tone_sld.setFocusPolicy(Qt.NoFocus)
-        self.tone_sld.setPageStep(1)
-        self.tone_sld.move(75, 275)
-        self.tone_sld.valueChanged.connect(
-            lambda val: self.tone_val.setText(str(val) + '%'))
-
-        # Pitch Slider
-        self.pitch_lbl = QLabel(self)
-        self.pitch_lbl.setText('Pitch:')
-        self.pitch_lbl.move(10, 300)
-        self.pitch_val = QLabel(self)
-        self.pitch_val.move(165, 300)
-        self.pitch_val.resize(35, 10)
-        self.pitch_val.setText('0%')
-        self.pitch_sld = QSlider(Qt.Horizontal, self)
-        self.pitch_sld.setRange(-100, 100)
-        self.pitch_sld.setFocusPolicy(Qt.NoFocus)
-        self.pitch_sld.setPageStep(1)
-        self.pitch_sld.move(75, 300)
-        self.pitch_sld.valueChanged.connect(
-            lambda val: self.pitch_val.setText(str(val) + '%'))
-
-        # Octave Sliders
+    # Octave Sliders
+        octave_tt = 'Increases or decreases the octaves by the number selected'
         self.octave_lbl = QLabel(self)
         self.octave_lbl.setText('Octave:')
-        self.octave_lbl.move(10, 325)
+        self.octave_lbl.move(8, 275)
+        self.octave_lbl.setToolTip(octave_tt)
         self.octave_val = QLabel(self)
-        self.octave_val.move(165, 325)
+        self.octave_val.move(170, 277)
         self.octave_val.resize(35, 10)
-        self.octave_val.setText('0%')
+        self.octave_val.setText('0')
+        self.octave_val.setFont(QFont('', 8))
+        self.octave_val.setToolTip(octave_tt)
         self.octave_sld = QSlider(Qt.Horizontal, self)
-        self.octave_sld.setRange(-100, 100)
+        self.octave_sld.setRange(-7, 7)
         self.octave_sld.setFocusPolicy(Qt.NoFocus)
         self.octave_sld.setPageStep(1)
-        self.octave_sld.move(75, 325)
+        self.octave_sld.move(90, 276)
+        self.octave_sld.resize(75,15)
+        self.octave_sld.setToolTip(octave_tt)
         self.octave_sld.valueChanged.connect(
-            lambda val: self.octave_val.setText(str(val) + '%'))
+            lambda val: self.octave_val.setText(str(val)))
             
-        # button to process file
+    # button to process file
         self.proc_file = QPushButton('Process...', self)
         self.proc_file.setGeometry(150, 150, 100, 40)
-        self.proc_file.move(50, 500)
+        self.proc_file.move(50, 400)
         self.proc_file.clicked.connect(self.process_file)
+        self.proc_lbl = QLabel('', self)
+        self.proc_lbl.move(53, 500)
+        self.proc_lbl.setFont(QFont('', 12))
 
-        # place holder for processed image
+    # error Label
+        self.error_lbl = QLabel('', self)
+        self.error_lbl.resize(300,15)
+        self.error_lbl.move(215, 173)
+
+
+    # create the canvas for drawing
         self.canvas = qt_canvas.QtCanvas(self)
-        self.canvas.move(200, 200)
+        self.canvas.move(210,200)
 
     def dark_mode(self):
         # https://gist.github.com/mstuttgart/37c0e6d8f67a0611674e08294f3daef7
@@ -178,7 +171,6 @@ class Window(QWidget):
         dark_palette.setColor(QPalette.Base, QColor(25, 25, 25))
         dark_palette.setColor(QPalette.AlternateBase, QColor(53, 53, 53))
         dark_palette.setColor(QPalette.ToolTipBase, Qt.white)
-        dark_palette.setColor(QPalette.ToolTipText, Qt.white)
         dark_palette.setColor(QPalette.Text, Qt.white)
         dark_palette.setColor(QPalette.Button, QColor(53, 53, 53))
         dark_palette.setColor(QPalette.ButtonText, Qt.white)
@@ -186,47 +178,46 @@ class Window(QWidget):
         dark_palette.setColor(QPalette.Link, QColor(42, 130, 218))
         dark_palette.setColor(QPalette.Highlight, QColor(42, 130, 218))
         dark_palette.setColor(QPalette.HighlightedText, Qt.black)
+        dark_palette.setColor(QPalette.ToolTipText, Qt.black)
         return dark_palette
 
     def pick_file(self):
         # https://pythonspot.com/pyqt5-file-dialog/
         # params for getOpenFileName are the window, the title, default file, file types
         file_name, _ = QFileDialog.getOpenFileName(
-            self, 'Select MP3 file', '', 'MP3 File (*.mp3)')
+            self, 'Select Audio file', '', 'Audio Files (*.mp3 *.wav)')
         if file_name:
             self.file_path.setText(file_name)
+            self.error_lbl.setText('')
 
     def on_algo_change(self):
         algo_desc = {
             '': '',
-            'Algorithm 1': 'Draw a collection of shapes and colors based on the notes and octaves',
-            'Algorithm 2': "A longer desctription for how algorithm 2 works with some of it's functionalities",
-            'Algorithm 3': 'Brief description for algorithm 3',
-            'Algorithm 4': 'Brief description for algorithm 4',
-            'Algorithm 5': 'Brief description for algorithm 5',
+            'Shape of You': 'Draw a collection of shapes based on notes and octaves',
+            'Line Rider': 'Draws a collection of lines based on notes and octaves',
+            'Curvy': 'Draws a collection of arcs based on notes and octaves',
         }
         self.algo_lbl.setText(algo_desc[self.algo_combo.currentText()])
         self.algo_lbl.resize(150, 80)
 
     def process_file(self):
-        if self.algo_combo.currentText() == 'Algorithm 1':
-            notes_to_canvas(self.file_path.text(),
-                            self.tempo_sld.value(), self.octave_sld.value())
-
-        # Test 1
-        img = tests.blank_image()
-        # Test 2
-        # img = tests.cairo_image()
-        # Test 3
-        # img = tests.layer()
-        # Test 4
-        # img = tests.circle()
-        qim = ImageQt(img)
-        proc_img = QPixmap.fromImage(qim)
-        # self.canvas.setPixmap(proc_img)
-        # self.canvas.adjustSize()
-        self.canvas.refresh()
+        if self.file_path.text()[-4:].lower() in ('.mp3', '.wav') and os.path.exists(self.file_path.text()):
+                self.error_lbl.setText('')
+                self.proc_lbl.setText('Processing...')
+                self.proc_lbl.adjustSize()
+                self.canvas.clear_args()
+                self.canvas.shapes = []
+                self.canvas.repaint()   
 
+                # p = multiprocessing.Process(target=shapes_algo.notes_to_canvas, args=(self.canvas,self.file_path.text(),self.sr_sld.value(),self.octave_sld.value()))
+                # p.start()
+                success = process_audio.proc_audio(self.algo_combo.currentText(),self.canvas, self.file_path.text(),
+                                    self.sr_sld.value(), self.octave_sld.value(), self.frq_sld.value())
+                self.proc_lbl.setText('')
+        else:
+            self.error_lbl.setText('<font color=red>Error: Invalid Audio File</font>')
+        if not success:
+             self.error_lbl.setText('<font color=red>Error Processing Audio File</font>')
 
 def main_func():
     set_display_to_host()
@@ -241,7 +232,7 @@ def main_func():
 def pip_main_func():
     # only called with pip package. Special changing of directory below
     print("Welcome to Synesthesia (installed via Pip)")
-    os.chdir('synesthesia')
+    # os.chdir('synesthesia')
     main_func()
 
 if __name__ == '__main__':
